/******************************* lcd.h *******************************/

#ifndef HEADER_LCD
#define HEADER_LCD

// uses commands specific to LCD2041

// control characters
#define LCD_BACKSPACE 0x08
#define LCD_NEW_PAGE 0x0C
#define LCD_CR 0x0D
#define LCD_LF 0x0A

#define LCD_START_COMMAND 0xFE


// pure commands, no arguments

#define LCD_AUTO_LINE_WRAP_ON 0x43
#define LCD_AUTO_LINE_WRAP_OFF 0x44
#define LCD_DISPLAY_OFF 0x46
#define LCD_GO_HOME 0x48
#define LCD_UNDERLINE_CURSOR_ON 0x4A
#define LCD_UNDERLINE_CURSOR_OFF 0x4B
#define LCD_CURSOR_BACK 0x4C
#define LCD_CURSOR_FORWARD 0x4D
#define LCD_AUTO_SCROLL_ON 0x51
#define LCD_AUTO_SCROLL_OFF 0x52
#define LCD_CURSOR_BLOCK_BLINKING_ON 0x53
#define LCD_CURSOR_BLOCK_BLINKING_OFF 0x54
#define LCD_CLEAR_SCREEN 0x58
#define LCD_INIT_HORIZONTAL_BAR 0x68
#define LCD_INIT_MEDIUM_NUM 0x6D
#define LCD_INIT_LARGE_NUM 0x6E
#define LCD_INIT_NARROW_VERTICAL_BAR 0x73
#define LCD_INIT_WIDE_VERTICAL_BAR 0x76


// commands with arguments

#define LCD_PLACE_LARGE_NUM 0x23
#define LCD_SET_I2C_SLAVE_ADDR 0x33 
#define LCD_SET_BAUD 0x39 
#define LCD_PLACE_VERTICAL_BAR 0x3D
#define LCD_SET_STARTUP_SCREEN 0x40
#define LCD_DISPLAY_ON 0x42
#define LCD_SET_CURSOR_POSITION 0x47 
#define LCD_CREATE_CUSTOM_CHAR 0x4E
#define LCD_SET_CONTRAST 0x50	 
#define LCD_GPO_OFF 0x56
#define LCD_GPO_ON 0x57	  
#define LCD_PLACE_MEDIUM_NUM 0x6F  
#define LCD_PLACE_HORIZONTAL_BAR 0x7C
#define LCD_SET_SAVE_CONSTRAST 0x91
#define LCD_SET_REMEMBER 0x93
#define LCD_SET_SAVE_BRIGHTNESS 0x98
#define LCD_SET_BRIGHTNESS 0x99
#define LCD_SET_BAUD_NONSTANDARD 0xA4
#define LCD_LOAD_CUSTOM_CHARS 0xC0
#define LCD_SAVE_CUSTOM_CHARS 0xC1
#define LCD_SAVE_STARTUP_CUSTOM_CHARS 0xC2
#define LCD_SET_STARTUP_GPO_STATE 0xC3


// FUNCTIONS

// sends a simple command to the LCD screen
void SendCommand(unsigned char command);

// sets the LCD backlight brightness
void SetBrightness(unsigned char value);

#endif
